@@ -1,6 +1,4 @@
 
-# As dBase is an old DOS format, Umlaute  are stored  using a different code table (CP437)
-#    (namely ASCII) than most modern unices (namely ANSI).
 taxname.abbr <- function(x, hybrid = c('ignore', 'TRUE', 'preserve', 'FALSE', 'substitute'), species = FALSE, cf = FALSE, ...) {
     hybrid <- as.character(hybrid)
     hybrid <- match.arg(hybrid, c('ignore', 'TRUE', 'preserve', 'FALSE', 'substitute'))
@@ -34,8 +32,10 @@ taxname.abbr <- function(x, hybrid = c('ignore', 'TRUE', 'preserve', 'FALSE', 's
     x <- sub('\ nothosubsp[.]' , '\ nothossp.', x, perl=TRUE, useBytes=TRUE)
     x <- sub('\ nothossp[.]' , '\ nssp.', x, perl=TRUE, useBytes=TRUE)
     x <- sub('\ nothovar[.]' , '\ nvar.', x, perl=TRUE, useBytes=TRUE)
+    
     if(hybrid %in% c('ignore', 'TRUE')) {
       x <- sub('\ x ' , '\ ', x, perl=TRUE, useBytes=TRUE)
+      x <- gsub('\U00D7 ', '', x)
       x <- sub('\ nssp[.]' , '\ ssp.', x, perl=TRUE, useBytes=TRUE)
       x <- sub('\ nvar[.]' , '\ var.', x, perl=TRUE, useBytes=TRUE)
     }
@@ -45,7 +45,7 @@ taxname.abbr <- function(x, hybrid = c('ignore', 'TRUE', 'preserve', 'FALSE', 's
       x <- sub('\ x\ ' , ' \u00d7\ ', x, perl=TRUE, useBytes=TRUE)
     }
 
-    if(cf) x <- sub('^cf.\ ', '', x, ignore.case=TRUE)
+    if(cf) x <- sub('cf.\ ', '', x, ignore.case=TRUE)
 		if(species)  {
       x <- sub('\ sp[.]', ' species', x, perl=TRUE, useBytes=TRUE)
       x <- sub('\ sp$', ' species', x, perl=TRUE, useBytes=TRUE)
@@ -62,23 +62,36 @@ taxname.abbr <- function(x, hybrid = c('ignore', 'TRUE', 'preserve', 'FALSE', 's
 }
 
 
-taxname.simplify <- function(x, genus=TRUE, epithet=TRUE, hybrid=TRUE, concept='ignore', ...) {
-#    x <- 'S\U00EBlixae calcarae subsp. holdae'
+taxname.simplify <- function(x, genus=TRUE, epithet=TRUE, hybrid=TRUE, concept.add='ignore', ...) {
     x <- gsub('\U00EB', 'e', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('\U00CF', 'i', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('ii', 'i', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('nn', 'n', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('fa', 'pha', x, perl=TRUE, useBytes=TRUE)
+    x <- gsub('oe', 'ae', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('ph', 'p', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('rh', 'h', x, perl=TRUE, useBytes=TRUE)
+    x <- gsub('rr', 'r', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('th', 't', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('tt', 't', x, perl=TRUE, useBytes=TRUE)
-    x <- gsub('y', 'i', x, perl=TRUE, useBytes=TRUE)
+    x <- gsub( 'y', 'i', x, perl=TRUE, useBytes=TRUE)
     x <- gsub('ranum', 'rianum', x, perl=TRUE, useBytes=TRUE)
-if(concept == 'ignore') {
+if(concept.add == 'ignore') {
   x <- gsub(' s[.] str[.]', '', x, perl=TRUE, useBytes=TRUE)
   x <- gsub(' s[.] l[.]', '', x, perl=TRUE, useBytes=TRUE)
 }
+if(genus) {
+  x <-	paste(sub('a$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
+  x <-	paste(sub('as$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
+  x <-	paste(sub('e$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
+  x <-	paste(sub('es$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
+  x <-	paste(sub('eus$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
+  x <-	paste(sub('is$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
+  x <-	paste(sub('on$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
+  x <-	paste(sub('u$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
+  x <-	paste(sub('um$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
+  x <-	paste(sub('us$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
+}
 if(epithet) {
     x <- paste(substr(x, 1, regexpr('\ ', x)-1), gsub('ae\\b', '', substr(x, regexpr('\ ', x), nchar(x))), sep='')
     x <- paste(substr(x, 1, regexpr('\ ', x)-1), gsub('arum\\b', '', substr(x, regexpr('\ ', x), nchar(x))), sep='')
@@ -101,21 +114,9 @@ if(epithet) {
     x <- paste(substr(x, 1, regexpr('\ ', x)-1), gsub('us\\b', '', substr(x, regexpr('\ ', x), nchar(x))), sep='')
     x <- paste(substr(x, 1, regexpr('\ ', x)-1), gsub('ae', 'e', substr(x, regexpr('\ ', x), nchar(x))), sep='')    
 }
-if(genus) {
-    x <-	paste(sub('a$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
-    x <-	paste(sub('as$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
-    x <-	paste(sub('e$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
-    x <-	paste(sub('es$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
-    x <-	paste(sub('eus$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
-    x <-	paste(sub('is$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
-    x <-	paste(sub('on$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
-    x <-	paste(sub('u$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
-    x <-	paste(sub('um$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
-    x <-	paste(sub('us$', '', substr(x, 1, regexpr('\ ', x)-1)), substr(x, regexpr('\ ', x), nchar(x)), sep='')
-}
 if(hybrid) {
 	x <- gsub(' x ', ' ', x)
-	x <- gsub('\U00D7', '', x)
+	x <- gsub('\U00D7 ', '', x)
 }
 return(x)
 }
@@ -160,7 +161,12 @@ TCS.replace <- function(x) {
   x <- replace(x, toupper(x) %in% c('ORGANISMIDENTITYNAME'), 'TaxonUsageID')
   x <- replace(x, toupper(x) %in% c('STRATUMNAME'), 'LAYER')
   x <- replace(x, toupper(x) %in% c('AGG_1_VALUE'), 'COVER_CODE')
-  
+
+## APG IV
+  x <- replace(x, toupper(x) %in% c('SCIENTIFICNAME'), 'TaxonName')
+  x <- replace(x, toupper(x) %in% c("TAXONRANK"), 'TaxonRank')
+  x <- replace(x, toupper(x) %in% c("PARENTNAMEUSAGE"), 'IsChildTaxonOf')
+
   return(x)
 }
 
@@ -174,8 +180,8 @@ TV.replace <- function(x) {
   x <- replace(x, toupper(x) %in% c('AGGNR', 'NAMEPARENTID', 'ISCHILDTAXONOFID'), 'AGG')
   x <- replace(x, toupper(x) %in% c('ISCHILDTAXONOF'), 'AGG_NAME')
   x <- replace(x, toupper(x) %in% c('ACCORDINGTO'), 'SECUNDUM')
-  x <- replace(x, toupper(x) %in% c("CommonName", 'VernacularName'), 'NATIVENAME')
-  x <- replace(x, toupper(x) %in% c('Classification'), 'CLASSIFICA')
+  x <- replace(x, toupper(x) %in% c("COMMONNAME", 'VERNACULARNAME'), 'NATIVENAME')
+  x <- replace(x, toupper(x) %in% c('CLASSIFICATION'), 'CLASSIFICA')
   x <- replace(x, toupper(x) %in% c('RANK', 'TAXONOMICRANK', 'TAXONRANK'), 'RANG')
   x <- replace(x, toupper(x) %in% c('NAMEAUTHOR', 'AUTHOR'), 'AUTHOR')
     
@@ -194,3 +200,52 @@ TV.replace <- function(x) {
   return(x)
 }
 
+taxname.removeAuthors <- function(x) {
+  removeAuthor <- function(x) {
+    if(length(gregexpr("[A-Z,\U181,\U193, \U044, \U268, \U044, \U381, \U044, \U352]", x)[[1]]) > 2) {
+      f <- if(grepl(' sect\\.', x, ignore.case = TRUE) | grepl('X ', x, fixed = TRUE) | grepl(' subg\\. ', x, ignore.case = TRUE)) 3 else 2
+      if(length(gregexpr("[A-Z,\U181,\U193, \U044, \U268, \U044, \U381, \U044, \U352]", x)[[1]]) >= f) {
+        s <- gregexpr("[A-Z,\U181,\U193, \U044, \U268, \U044, \U381, \U044, \U352]", x)[[1]][f]
+        if(s > 1) x <- substr(x, 1, s-2)
+        s <- gregexpr("(", x, fixed=TRUE)[[1]][1]
+        if(s > 0) x <- substr(x, 1, s-2)
+        x <- trimws(x)
+      }}
+    return(x)
+  }
+  out <- sapply(x, function(y) removeAuthor(y))
+  return(out)
+}
+
+parse.taxa <- function(x, epis) {
+  warning('Function does not account for "Sect./Ser." etc., nor for intraspecific taxa without specifier ("subsp./var." etc. or aggregates ("agg.")') 
+  simpleCap <- function(x) {
+    s <- strsplit(x, " ")[[1]]
+    paste(toupper(substring(s, 1,1)), tolower(substring(s, 2)),
+          sep="", collapse=" ")
+  }
+  
+  if(missing(epis)) epis <- c('subsp.', 'var.', 'v.')
+  original <- x
+  x <- taxname.abbr(x, species = TRUE)
+  x <- sub(' sp.', replacement = '', x = x, fixed = TRUE)
+  x <- sub(' spec.', replacement = '', x = x, fixed = TRUE)
+  x <- sub(' SP.', replacement = '', x = x, fixed = TRUE)
+  x <- sub(' SPEC.', replacement = '', x = x, fixed = TRUE)
+  genus <- sapply(x, stringr::word, 1)
+  genus <- sapply(genus, simpleCap)
+  epi1 <- sapply(x, stringr::word, 2)
+  intra <- sapply(epis, function(y) grepl(y, x, fixed = TRUE))
+  rang.suff <- as.character(apply(intra, 1, function(x) epis[x]))
+  epi2 <- character(length = length(x))
+  if(any(intra)) for(i in 1:length(x)) if(rang.suff[i] != 'character(0)') epi2[i] <- paste(rang.suff[i], stringr::word(strsplit(x[i], rang.suff[i], fixed = TRUE)[[1]][2],2))
+  species <- trimws(paste(genus, tolower(epi1), tolower(epi2)))
+  species[species == "NA NA"] <- ''
+  species <- sub(' NA', replacement = '', x = species, fixed = TRUE)
+  epi2 <-  sub('subsp. ', replacement = '', x = epi2, fixed = TRUE)
+  result <- data.frame(original, genus, epi1=tolower(epi1), rang.suff= if(length(rang.suff)>0) rang.suff else NA, epi2, scientificName = species)
+  result$rang.suff[result$rang.suff == 'character(0)'] <- NA
+  return(result)
+}
+# parse.taxa(x)
+# add.legal <- c('-',';')
