@@ -2,7 +2,6 @@
 library(knitr)
 options(stringsAsFactors=FALSE)
 opts_chunk$set(concordance = TRUE, comment = "", warning = FALSE, message = TRUE, echo = TRUE, results = 'tex', size="footnotesize")
-# read_chunk("some/script/I/want/to/load.R")
 tmp <- tempdir()
 suppressPackageStartupMessages(library(vegdata))
 options(tv_home = tmp)
@@ -17,18 +16,21 @@ file.copy(from = file.path(path.package("vegdata"), 'tvdata', 'Data'), to = tmp,
 library(vegdata)
 
 ## ----eval=TRUE-----------------------------------------------------------
-h <- tv.home()
+tv_home <- tv.home()
 
 ## ----eval=FALSE----------------------------------------------------------
 #  options(tv_home="path_to_your_Turboveg_root_directory")
 
-## ----dblisting, eval=FALSE-----------------------------------------------
-#  tv.db()
+## ----dblisting-----------------------------------------------------------
+tv.db()
 
 ## ------------------------------------------------------------------------
 tv.refl()
 
-## ----tax-----------------------------------------------------------------
+## ----eval=FALSE----------------------------------------------------------
+#  tv.refl('your_preferred_list')
+
+## ----tax, eval =TRUE-----------------------------------------------------
 tax('Brachythecium rutabulum')
 
 ## ----syn-----------------------------------------------------------------
@@ -36,8 +38,8 @@ tax('Elytrigia repens')$TaxonName
 syn('Elytrigia repens')
 
 ## ----childs, eval=FALSE--------------------------------------------------
-#  childs(27, quiet=TRUE)$TaxonName
-#  parents('ACHIMIL')
+#  child(27, quiet=TRUE)$TaxonName
+#  parent('ACHIMIL')
 
 ## ----db------------------------------------------------------------------
 db <- 'taxatest'
@@ -49,13 +51,12 @@ db <- 'taxatest'
 getOption('tv_home')
 obs.tax <- tv.obs(db)
 # Adding species names
-species <- tax('all')
+species <- tax('all', refl=tv.refl(db=db))
 obs.tax$TaxonName <-  species$TaxonName[match(obs.tax$TaxonUsageID, species$TaxonUsageID)]
 head(obs.tax[,c('RELEVE_NR','TaxonUsageID','COVER_CODE','LAYER','TaxonName')])
 
 ## ----taxval, eval=TRUE---------------------------------------------------
-obs.tax$OriginalName <- obs.tax$TaxonName
-obs.taxval <- taxval(obs.tax, db=db, mono='lower', maxtaxlevel='AGG', interactive=FALSE)
+obs.taxval <- taxval(obs.tax, db=db, maxtaxlevel='AGG', interactive=FALSE, check.critical = TRUE)
 
 ## ----Taxon---------------------------------------------------------------
 obs.taxval$OriginalName <- obs.taxval$TaxonName
@@ -63,8 +64,9 @@ obs.taxval$TaxonName <-  species$TaxonName[match(obs.taxval$TaxonUsageID, specie
 obs.taxval[!duplicated(obs.taxval$OriginalName),c('RELEVE_NR', 'COVER_CODE', 'TaxonName', 'OriginalName')]
 
 ## ----coarsen, eval=TRUE, results='hide'----------------------------------
-tmp <- taxval(obs.tax, refl='GermanSL 1.3', ag='adapt', maxtaxlevel = 'ROOT', rank='FAM')
-tmp$newTaxon <- tax(tmp$TaxonUsageID, refl='GermanSL 1.3')$TaxonName
+obs.tax$OriginalName <-obs.tax$TaxonName
+tmp <- taxval(obs.tax, db=db, ag='adapt', maxtaxlevel = 'ROOT', rank='FAM', check.critical = FALSE)
+tmp$newTaxon <- tax(tmp$TaxonUsageID, db=db)$TaxonName
 
 ## ----print.coarsen-------------------------------------------------------
 head(tmp[,c('OriginalName','newTaxon')], 10)
@@ -92,8 +94,6 @@ names(tv.veg(db, tax=FALSE, pseudo=comb, quiet=TRUE))
 ## ----layer, results='hide', warning=FALSE-------------------------------------------------------------------
 data(lc.1)
 veg <- tv.veg(db, lc = "sum", pseudo = list(lc.1, 'LAYER'), dec = 1, check.critical = FALSE)
-
-## ----layerdiff----------------------------------------------------------------------------------------------
 veg[,1:10]
 
 ## -----------------------------------------------------------------------------------------------------------
@@ -102,7 +102,7 @@ obs.tax$TaxonUsageID[obs.tax$TaxonUsageID == 27] <- 31
 ## ----replace------------------------------------------------------------------------------------------------
 taxon.repl <- data.frame(old=c(27), new=c(31))
 obs.tax$TaxonUsageID <- replace(obs.tax$TaxonUsageID, 
-    match(taxon.repl$old, obs.tax$TaxonUsageID), taxon.repl$new)
+                                match(taxon.repl$old, obs.tax$TaxonUsageID), taxon.repl$new)
 
 ## ----comb.spec, eval=FALSE----------------------------------------------------------------------------------
 #  comb.species(veg, sel=c('QUERROB','QUERROB.Tree'))
@@ -111,7 +111,7 @@ obs.tax$TaxonUsageID <- replace(obs.tax$TaxonUsageID,
 site <- tv.site(db)
 
 ## ----elbaue, results='hide'---------------------------------------------------------------------------------
-elbaue <- tv.veg('elbaue')
+elbaue <- tv.veg('elbaue', check.critical = FALSE)
 elbaue.env <- tv.site('elbaue')
 
 ## ----cluster------------------------------------------------------------------------------------------------
@@ -134,38 +134,38 @@ rownames(trait) <- trait$LETTERCODE
 trait <- trait[,c('OEK_F', 'OEK_N')]
 print(st, limit=30, trait=trait)
 
-## ----nmds, quiet=TRUE, results='hide', eval=TRUE------------------------------------------------------------
+## ----nmds, quiet=TRUE, results='hide'-----------------------------------------------------------------------
 ## Data analyses
 library(vegan)
 veg.nmds <- metaMDS(elbaue, distance = "bray", trymax = 5, autotransform =FALSE, 
-     noshare = 1, expand = TRUE, trace = 2)
-eco <- tv.traits()
-eco$OEK_F <- as.numeric(eco$OEK_F)
-F <- isc(elbaue, trait.db = eco, ivname = 'OEK_F', method = 'mean')
-N <- isc(elbaue, trait.db = eco, ivname = 'OEK_N', method = 'mean')
-env <- envfit(veg.nmds, data.frame(F, N))
+                    noshare = 1, expand = TRUE, trace = 2)
+#eco <- tv.traits()
+#eco$OEK_F <- as.numeric(eco$OEK_F)
+F <- isc(elbaue, trait.db = 'ecodbase.dbf', ivname = 'OEK_F', method = 'mean')
+N <- isc(elbaue, trait.db = 'ecodbase.dbf', ivname = 'OEK_N', method = 'mean')
+env <- envfit(veg.nmds, env = data.frame(F, N))
 
 ## ----nmdsplotfun, quiet=TRUE, results='hide'----------------------------------------------------------------
 library(labdsv)
 library(akima)
 color = function(x)rev(topo.colors(x))
 nmds.plot <- function(ordi, site, var1, var2, disp, plottitle =  'NMDS', env = NULL, ...) {
- lplot <- nrow(ordi$points);  lspc <- nrow(ordi$species)
- filled.contour(interp(ordi$points[, 1], ordi$points[, 2], site[, var1]), 
-                ylim = c(-1, 1.1), xlim = c(-1.4, 1.4),
-   color.palette = color, xlab = var1, ylab = var2, main = plottitle,
-    key.title = title(main = var1, cex.main = 0.8, line = 1, xpd = NA),
-    plot.axes = { axis(1);  axis(2)
-      points(ordi$points[, 1], ordi$points[, 2], xlab = "", ylab = "", cex= .5, col = 2, pch = '+')
-      points(ordi$species[, 1], ordi$species[, 2], xlab = "", ylab = "", cex=.2, pch = 19)
-      ordisurf(ordi, site[, var2], col = 'black', choices = c(1, 2), add = TRUE)
-      orditorp(ordi, display = disp, pch = " ")
-      legend("topright", paste("GAM of ", var2), col = 'black', lty = 1)
-      if(!is.null(env)) plot(env, col='red')
-   }
-  ,...)
+lplot <- nrow(ordi$points);  lspc <- nrow(ordi$species)
+filled.contour(interp(ordi$points[, 1], ordi$points[, 2], site[, var1]), 
+           ylim = c(-1, 1.1), xlim = c(-1.4, 1.4),
+           color.palette = color, xlab = var1, ylab = var2, main = plottitle,
+           key.title = title(main = var1, cex.main = 0.8, line = 1, xpd = NA),
+           plot.axes = { axis(1);  axis(2)
+             points(ordi$points[, 1], ordi$points[, 2], xlab = "", ylab = "", cex= .5, col = 2, pch = '+')
+             points(ordi$species[, 1], ordi$species[, 2], xlab = "", ylab = "", cex=.2, pch = 19)
+             ordisurf(ordi, site[, var2], col = 'black', choices = c(1, 2), add = TRUE)
+             orditorp(ordi, display = disp, pch = " ")
+             legend("topright", paste("GAM of ", var2), col = 'black', lty = 1)
+             if(!is.null(env)) plot(env, col='red')
+           }
+           ,...)
 }
 
-## ----nmdsplot, quiet=TRUE, results='hide', eval=TRUE, warning=FALSE-----------------------------------------
- nmds.plot(veg.nmds, elbaue.env, disp='species', var1="MGL", var2="SDGL", env=env, plottitle = 'Elbaue floodplain dataset')
+## ----nmdsplot, quiet=TRUE, results='hide', eval=TRUE, warning=FALSE, eval=TRUE------------------------------
+nmds.plot(veg.nmds, elbaue.env, disp='species', var1="MGL", var2="SDGL", env=env, plottitle = 'Elbaue floodplain dataset')
 
